/**
 Listener hook just fires functions passed to hook function when executor is invoked.
 e. g. We want to listen for onAppInit event in various places of the application.
 Functions passed to this hook will be invoked only when executor function is executed.
 Usually we want to use hook in app/modules and executor in core.
 @return hook:  a hook function to use in modules
 @return executor: a function that will run all the collected hooks
 */
export declare function createListenerHook<T>(): {
    hook: (fn: (arg?: T) => void) => void;
    executor: (args?: T) => void;
};
/**
 Mutators work like listeners except they can modify passed value in hooks.
 e.g we can apply the hook mutator to object order that is returned before placing order
 now you can access and modify this value from hook returned by this function
 @return hook: a hook function to use in modules
 @return executor: a function that will apply all hooks on a given value
 */
export declare function createMutatorHook<T, R>(): {
    hook: (mutator: (arg: T) => R) => void;
    executor: (rawOutput: T) => T | R;
};
